/**************************************************************************
*   Copyright (C) 2003 by Hideki Ikemoto , (c)2004 by 421                 *
*   ikemo@wakaba.jp                                                       *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
**************************************************************************/

/* UTF-8 japanese strings  */

#define KITAUTF8_ZENSPACE "　"
#define KITAUTF8_EXTRACT "抽出"
#define KITAUTF8_NOWRENEW " 更新中・・・"
#define KITAUTF8_NOWEXPAND " 展開中・・・"
#define KITAUTF8_INCACHE "キャッシュ済"
#define KITAUTF8_KOKOYON  "ここまで読んだ"
#define KITAUTF8_KOKOYON2 "──────────ここまで読んだ──────────"
#define KITAUTF8_TEMPLATE "──────────テンプレート──────────"
#define KITAUTF8_COLON "："
#define KITAUTF8_BTITLE "板看板"
#define KITAUTF8_NAME "名前："
#define KITAUTF8_ZENBU  "全部"
#define KITAUTF8_ZENBUNOKORI  "残り全部"
#define KITAUTF8_TUGI100 "次100"
#define KITAUTF8_ZENBUMAE  "前全部"
#define KITAUTF8_MAE100 "前100"
#define KITAUTF8_SAIGO  "最後"
#define KITAUTF8_KOWARE   "ここは壊れています。"
#define KITAUTF8_ABONE  "あぼーん"
#define KITAUTF8_GOTO  "移動"
#define KITAUTF8_FRAME1 "│"
#define KITAUTF8_FRAME2 "├"
#define KITAUTF8_FRAME3 "└"

#define KITAUTF8_HEART    "♥"
#define KITAUTF8_DIA      "♦"
#define KITAUTF8_CLUB     "♣"
#define KITAUTF8_SPADE    "♠"

#define  KITAUTF8_MONDAY "（月）"
#define  KITAUTF8_TUESDAY "（火）"
#define  KITAUTF8_WEDNESDAY "（水）"
#define  KITAUTF8_THURSDAY "（木）"
#define  KITAUTF8_FRIDAY "（金）"
#define  KITAUTF8_SATURDAY "（土）"
#define  KITAUTF8_SUNDAY "（日）"


/* for writing */

#define  KITAUTF8_WRITEERROR "ＥＲＲＯＲ"
#define  KITAUTF8_WRITETRUE "書きこみました"
#define  KITAUTF8_WRITECOOKIE "書き込み確認"
#define  KITAUTF8_WRITECOOKIEMSG  "投稿確認\n・投稿者は、投稿に関して発生する責任が全て投稿者に帰すことを承諾します。\n・投稿者は、話題と無関係な広告の投稿に関して、相応の費用を支払うことを承諾します\n・投稿者は、投稿された内容及びこれに含まれる知的財産権、（著作権法第21条ないし第28条に規定される権利も含む）その他の権利につき、掲示板運営者及びその指定する者に対し、これらを日本国内外において無償で非独占的に利用する一切の権利（第三者に対して再許諾する権利を含みます。）を許諾することを承諾します。また、掲示板運営者が指定する第三者に対して、一切の権利（第三者に対して再許諾する権利を含みます。）を許諾しないことを承諾します。\n・投稿者は、掲示板運営者に対して、著作者人格権を一切行使しないことを承諾します。・投稿された内容はコピー、保存、引用、転載等される場合があります。\n・投稿に関して発生する責任は全て投稿者に帰します。\n\n全責任を負うことを承諾して書き込みますか\n"
#define  KITAUTF8_WRITENEWTHREAD  "書き込みに関して様々なログ情報が記録されています。\n公序良俗に反したり、他人に迷惑をかける書き込みは控えて下さい"
